@@ -10,27 +10,41 @@
 #
 import datetime
 import os
+import pathlib
 import sys
 
-import sphinx_material_saltstack
+from sphinx.directives.code import LiteralInclude
 
 try:
-    docs_basepath = os.path.abspath(os.path.dirname(__file__))
+    from importlib.metadata import version as pkg_version
+except ImportError:
+    from importlib_metadata import version as pkg_version
+
+import pytest
+
+try:
+    pytest.helpers
+except AttributeError:
+    from pytest_helpers_namespace.plugin import HelpersRegistry
+
+    pytest.helpers = HelpersRegistry()
+
+try:
+    DOCS_BASEPATH = pathlib.Path(__file__).resolve().parent
 except NameError:
     # sphinx-intl and six execute some code which will raise this NameError
     # assume we're in the doc/ directory
-    docs_basepath = os.path.abspath(os.path.dirname("."))
+    DOCS_BASEPATH = pathlib.Path(".").resolve().parent
+
+REPO_ROOT = DOCS_BASEPATH.parent
 
 addtl_paths = (
-    os.pardir,  # saltfactories itself (for autodoc)
-    "_ext",  # custom Sphinx extensions
+    DOCS_BASEPATH / "_ext",  # custom Sphinx extensions
+    REPO_ROOT / "src",  # saltfactories itself (for autodoc)
 )
 
 for addtl_path in addtl_paths:
-    sys.path.insert(0, os.path.abspath(os.path.join(docs_basepath, addtl_path)))
-
-import saltfactories
-
+    sys.path.insert(0, addtl_path)
 
 # -- Project information -----------------------------------------------------
 this_year = datetime.datetime.today().year
@@ -39,12 +53,11 @@ if this_year == 2020:
 else:
     copyright_year = f"2020 - {this_year}"
 project = "PyTest Salt Factories"
-copyright = f"{copyright_year}, SaltStack, Inc."
-author = "SaltStack, Inc."
+copyright = f"{copyright_year}, VMware, Inc."
+author = "VMware, Inc."
 
 # The full version, including alpha/beta/rc tags
-release = saltfactories.__version__
-
+release = pkg_version("pytest-salt-factories")
 
 # Variables to pass into the docs from sitevars.rst for rst substitution
 with open("sitevars.rst") as site_vars_file:
@@ -62,15 +75,16 @@ rst_prolog = """
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    "sphinx_material_saltstack",
     "sphinx.ext.autodoc",
     "sphinx.ext.autosummary",
-    "sphinx.ext.napoleon",
+    "sphinx_copybutton",
+    # "sphinx.ext.napoleon",
     "sphinx.ext.intersphinx",
     "sphinx.ext.viewcode",
     "sphinx.ext.todo",
     "sphinx.ext.coverage",
     "sphinxcontrib.spelling",
+    "sphinxcontrib.towncrier",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -92,36 +106,24 @@ exclude_patterns = [
 ]
 
 autosummary_generate = True
-
+modindex_common_prefix = ["saltfactories."]
+master_doc = "contents"
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = "sphinx_material_saltstack"
-html_theme_path = sphinx_material_saltstack.html_theme_path()
-html_context = sphinx_material_saltstack.get_html_context()
-html_sidebars = {"**": ["logo-text.html", "globaltoc.html", "localtoc.html", "searchbox.html"]}
+html_theme = "furo"
+html_title = project
 html_theme_options = {
-    # Set the name of the project to appear in the navigation.
-    "nav_title": "PyTest Salt Factories",
-    # Set you GA account ID to enable tracking
-    # "google_analytics_account": "",
-    # Set the repo location to get a badge with stats (only if public repo)
-    "repo_url": "https://github.com/saltstack/pytest-salt-factories",
-    "repo_name": "pytest-salt-factories",
-    "repo_type": "github",
-    # Visible levels of the global TOC; -1 means unlimited
-    "globaltoc_depth": 1,
-    # If False, expand all TOC entries
-    "globaltoc_collapse": False,
-    # If True, show hidden TOC entries
-    "globaltoc_includehidden": True,
-    # hide tabs?
-    "master_doc": False,
-    # Minify for smaller HTML/CSS assets
-    "html_minify": True,
-    "css_minify": True,
+    "light_logo": "img/SaltProject_altlogo_teal.png",
+    "dark_logo": "img/SaltProject_altlogo_teal.png",
+    "announcement": (
+        "<b>"
+        "Documentation is always evolving, but this one hasn't reached it's prime for a 1.0.0 release. "
+        "Once we reach that stage, this warning will go away."
+        "</b>"
+    ),
 }
 
 # Add any paths that contain custom static files (such as style sheets) here,
@@ -129,27 +131,17 @@ html_theme_options = {
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ["_static"]
 
-# The name of an image file (relative to this directory) to place at the top
-# of the sidebar.
-html_logo = os.path.join(
-    html_theme_path[0],
-    "sphinx_material_saltstack",
-    "static",
-    "images",
-    "saltstack-logo.png",
-)
+# These paths are either relative to html_static_path
+# or fully qualified paths (eg. https://...)
+html_css_files = [
+    "css/inline-include.css",
+]
 
 # The name of an image file (within the static path) to use as favicon of the
 # docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
 # pixels large. Favicons can be up to at least 228x228. PNG
 # format is supported as well, not just .ico'
-html_favicon = os.path.join(
-    html_theme_path[0],
-    "sphinx_material_saltstack",
-    "static",
-    "images",
-    "favicon.png",
-)
+html_favicon = "_static/img/SaltProject_Logomark_teal.png"
 
 # Sphinx Napoleon Config
 napoleon_google_docstring = True
@@ -167,18 +159,64 @@ napoleon_use_rtype = True
 # ----- Intersphinx Config ---------------------------------------------------------------------------------------->
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
-    "pytest": ("https://pytest.readthedocs.io/en/stable", None),
-    "salt": ("https://docs.saltstack.com/en/latest", None),
+    "pytest": ("https://docs.pytest.org/en/stable/", None),
+    "salt": ("https://docs.saltproject.io/en/latest", None),
+    "psutil": ("https://psutil.readthedocs.io/en/latest/", None),
+    "coverage": ("https://coverage.readthedocs.io/en/latest/", None),
 }
 # <---- Intersphinx Config -----------------------------------------------------------------------------------------
 
 # ----- Autodoc Config ---------------------------------------------------------------------------------------------->
 autodoc_default_options = {"member-order": "bysource"}
 autodoc_mock_imports = ["salt"]
+autodoc_typehints = "description"
 # <---- Autodoc Config -----------------------------------------------------------------------------------------------
 
 
+# ----- Towncrier Draft Release ------------------------------------------------------------------------------------->
+# Options: draft/sphinx-version/sphinx-release
+towncrier_draft_autoversion_mode = "draft"
+towncrier_draft_include_empty = True
+towncrier_draft_working_directory = REPO_ROOT
+# Not yet supported:
+# towncrier_draft_config_path = 'pyproject.toml'  # relative to cwd
+# <---- Towncrier Draft Release --------------------------------------------------------------------------------------
+
+
+# ----- Literal Include - Auto Caption ------------------------------------------------------------------------------>
+
+
+class IncludeExample(LiteralInclude):
+    """
+    The first argument to the directive is the file path relative to the repository root
+
+    .. code-block:: rst
+
+        .. include-example:: relative/path/to/example.py
+
+    """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.example_file = self.arguments[0]
+        # Get the current doc path relative to the docs directory
+        rel_current_source = os.path.relpath(DOCS_BASEPATH, self.state.document.current_source)
+        # Now, the passed filename, relative to the current doc, so that including it actually works
+        self.arguments[0] = os.path.join(rel_current_source, self.example_file)
+
+    def run(self):
+        if "caption" not in self.options:
+            self.options["caption"] = self.example_file
+        if "name" not in self.options:
+            self.options["name"] = self.example_file
+        return super().run()
+
+
+# <---- Literal Include - Auto Caption -------------------------------------------------------------------------------
+
+
 def setup(app):
+    app.add_directive("include-example", IncludeExample)
     app.add_crossref_type(
         directivename="fixture",
         rolename="fixture",
