@@ -20,7 +20,7 @@ def salt_run_cli(master):
 
 @pytest.fixture
 def salt_cli(master):
-    return master.get_salt_cli()
+    return master.salt_cli()
 
 
 @pytest.fixture
