@@ -9,9 +9,9 @@ import attr
 import psutil
 import pytest
 
+from saltfactories.bases import Daemon
 from saltfactories.exceptions import FactoryNotRunning
 from saltfactories.exceptions import FactoryNotStarted
-from saltfactories.factories.base import DaemonFactory
 from saltfactories.utils import platform
 from saltfactories.utils.processes import _get_cmdline
 
@@ -20,7 +20,7 @@ PROCESS_START_TIMEOUT = 2
 log = logging.getLogger(__name__)
 
 
-def kill_children(procs):  # pragma: nocover
+def kill_children(procs):  # pragma: no cover
     _, alive = psutil.wait_procs(procs, timeout=3)
     for p in alive:
         p.kill()
@@ -87,11 +87,11 @@ def test_daemon_process_termination(request, tempfiles):
         executable=True,
     )
     if not platform.is_windows():
-        factory_kwargs = dict(cli_script_name=script)
+        factory_kwargs = dict(script_name=script)
     else:
         # Windows don't know how to handle python scripts directly
-        factory_kwargs = dict(cli_script_name=sys.executable, base_script_args=[script])
-    daemon = DaemonFactory(start_timeout=1, **factory_kwargs)
+        factory_kwargs = dict(script_name=sys.executable, base_script_args=[script])
+    daemon = Daemon(start_timeout=1, **factory_kwargs)
     daemon.start()
     daemon_pid = daemon.pid
     # Make sure the daemon is terminated no matter what
@@ -115,7 +115,7 @@ def test_daemon_process_termination(request, tempfiles):
     )
     daemon.terminate()
     assert psutil.pid_exists(daemon_pid) is False
-    for child in list(children):  # pragma: nocover
+    for child in list(children):  # pragma: no cover
         if psutil.pid_exists(child.pid):
             continue
         children.remove(child)
@@ -186,11 +186,11 @@ def test_daemon_process_termination_parent_killed(request, tempfiles):
         executable=True,
     )
     if not platform.is_windows():
-        factory_kwargs = dict(cli_script_name=script)
+        factory_kwargs = dict(script_name=script)
     else:
         # Windows don't know how to handle python scripts directly
-        factory_kwargs = dict(cli_script_name=sys.executable, base_script_args=[script])
-    daemon = DaemonFactory(start_timeout=1, **factory_kwargs)
+        factory_kwargs = dict(script_name=sys.executable, base_script_args=[script])
+    daemon = Daemon(start_timeout=1, **factory_kwargs)
     daemon.start()
     daemon_pid = daemon.pid
     # Make sure the daemon is terminated no matter what
@@ -243,8 +243,8 @@ def test_started_context_manager(request, tempfiles, start_timeout):
         """,
         executable=True,
     )
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[script],
         start_timeout=2,
         max_start_attempts=1,
@@ -268,7 +268,7 @@ def test_started_context_manager(request, tempfiles, start_timeout):
         started = None
         with daemon.started(start_timeout=start_timeout):
             # We should not even be able to set the following variable
-            started = False  # pragma: nocover
+            started = False  # pragma: no cover
     assert started is None
     match = re.search(r"which took (?P<seconds>.*) seconds", str(exc.value))
     assert match
@@ -318,8 +318,8 @@ def factory_stopped_script(tempfiles):
 
 
 def test_stopped_context_manager_raises_FactoryNotRunning(request, factory_stopped_script):
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[factory_stopped_script],
         start_timeout=3,
         max_start_attempts=1,
@@ -334,8 +334,8 @@ def test_stopped_context_manager_raises_FactoryNotRunning(request, factory_stopp
 
 
 def test_stopped_context_manager(request, factory_stopped_script):
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[factory_stopped_script],
         start_timeout=3,
         max_start_attempts=1,
@@ -378,8 +378,8 @@ class CallbackState:
 
 def test_stopped_context_manager_callbacks(request, factory_stopped_script):
 
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[factory_stopped_script],
         start_timeout=3,
         max_start_attempts=1,
@@ -460,8 +460,8 @@ def test_context_manager_returns_class_instance(tempfiles):
         """,
         executable=True,
     )
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[script],
         start_timeout=1,
         max_start_attempts=1,
@@ -472,7 +472,7 @@ def test_context_manager_returns_class_instance(tempfiles):
     with pytest.raises(RuntimeError):
         with daemon as d:
             # We should not even be able to set the following variable
-            started = d.is_running()  # pragma: nocover
+            started = d.is_running()  # pragma: no cover
     assert d is None
     assert started is None
 
@@ -526,8 +526,8 @@ def test_exact_max_start_attempts(tempfiles, caplog, max_start_attempts):
         """,
         executable=True,
     )
-    daemon = DaemonFactory(
-        cli_script_name=sys.executable,
+    daemon = Daemon(
+        script_name=sys.executable,
         base_script_args=[script],
         start_timeout=0.1,
         max_start_attempts=max_start_attempts,
@@ -543,7 +543,7 @@ def test_exact_max_start_attempts(tempfiles, caplog, max_start_attempts):
         "Attempt: {} of {}".format(n, max_start_attempts) for n in range(1, max_start_attempts + 1)
     ]
     for record in caplog.records:
-        if not record.message.startswith("Starting DaemonFactory"):
+        if not record.message.startswith("Starting Daemon"):
             continue
         for idx, start_attempt in enumerate(list(start_attempts)):
             if start_attempt in record.message:
