@@ -8,15 +8,11 @@ import pathlib
 
 
 def test_version_info(salt_minion, salt_proxy_minion, salt_version):
-    cli = salt_minion.get_salt_call_cli()
+    cli = salt_minion.salt_call_cli()
     ret = cli.run("--version")
     assert ret.exitcode == 0, ret
-    assert ret.stdout.strip() == "{} {}".format(
-        pathlib.Path(cli.cli_script_name).name, salt_version
-    )
-    cli = salt_proxy_minion.get_salt_call_cli()
+    assert ret.stdout.strip() == "{} {}".format(pathlib.Path(cli.script_name).name, salt_version)
+    cli = salt_proxy_minion.salt_call_cli()
     ret = cli.run("--version")
     assert ret.exitcode == 0, ret
-    assert ret.stdout.strip() == "{} {}".format(
-        pathlib.Path(cli.cli_script_name).name, salt_version
-    )
+    assert ret.stdout.strip() == "{} {}".format(pathlib.Path(cli.script_name).name, salt_version)
