@@ -4,73 +4,73 @@ from saltfactories.utils import random_string
 from saltfactories.utils import running_username
 
 
-def test_keyword_basic_config_defaults(salt_factories):
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_defaults={"zzzz": True}
+def test_keyword_basic_defaults(salt_factories):
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), defaults={"zzzz": True}
     ).config
     assert "zzzz" in minion_config
 
 
-def test_interface_config_defaults(salt_factories):
+def test_interface_defaults(salt_factories):
     interface = "172.17.0.1"
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_defaults={"interface": interface}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), defaults={"interface": interface}
     ).config
     assert minion_config["interface"] != interface
     assert minion_config["interface"] == "127.0.0.1"
 
 
-def test_master_config_defaults(salt_factories):
+def test_master_defaults(salt_factories):
     master = "172.17.0.1"
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_defaults={"master": master}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), defaults={"master": master}
     ).config
     assert minion_config["master"] != master
     assert minion_config["master"] == "127.0.0.1"
 
 
-def test_keyword_basic_config_overrides(salt_factories):
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_overrides={"zzzz": True}
+def test_keyword_basic_overrides(salt_factories):
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), overrides={"zzzz": True}
     ).config
     assert "zzzz" in minion_config
 
 
-def test_interface_config_overrides(salt_factories):
+def test_interface_overrides(salt_factories):
     interface = "172.17.0.1"
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_overrides={"interface": interface}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), overrides={"interface": interface}
     ).config
     assert minion_config["interface"] == interface
     assert minion_config["interface"] != "127.0.0.1"
 
 
-def test_master_config_overrides(salt_factories):
+def test_master_overrides(salt_factories):
     master = "172.17.0.1"
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_overrides={"master": master}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), overrides={"master": master}
     ).config
     assert minion_config["master"] == master
     assert minion_config["master"] != "127.0.0.1"
 
 
 def test_keyword_simple_overrides_override_defaults(salt_factories):
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_defaults={"zzzz": False}, config_overrides={"zzzz": True}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), defaults={"zzzz": False}, overrides={"zzzz": True}
     ).config
     assert "zzzz" in minion_config
     assert minion_config["zzzz"] is True
 
 
 def test_keyword_nested_overrides_override_defaults(salt_factories):
-    minion_config = salt_factories.get_salt_minion_daemon(
+    minion_config = salt_factories.salt_minion_daemon(
         random_string("minion-"),
-        config_defaults={
+        defaults={
             "zzzz": False,
             "user": "foobar",
             "colors": {"black": True, "white": False},
         },
-        config_overrides={"colors": {"white": True, "grey": False}},
+        overrides={"colors": {"white": True, "grey": False}},
     ).config
     assert "zzzz" in minion_config
     assert minion_config["zzzz"] is False
@@ -79,9 +79,9 @@ def test_keyword_nested_overrides_override_defaults(salt_factories):
 
 def test_provide_root_dir(pytester, salt_factories):
     root_dir = str(pytester.mkdir("custom-root"))
-    config_defaults = {"root_dir": root_dir}
-    minion_config = salt_factories.get_salt_minion_daemon(
-        random_string("minion-"), config_defaults=config_defaults
+    defaults = {"root_dir": root_dir}
+    minion_config = salt_factories.salt_minion_daemon(
+        random_string("minion-"), defaults=defaults
     ).config
     assert minion_config["root_dir"] == root_dir
 
@@ -92,11 +92,11 @@ def configure_kwargs_ids(value):
 
 @pytest.mark.parametrize(
     "configure_kwargs",
-    [{"config_defaults": {"user": "blah"}}, {"config_overrides": {"user": "blah"}}, {}],
+    [{"defaults": {"user": "blah"}}, {"overrides": {"user": "blah"}}, {}],
     ids=configure_kwargs_ids,
 )
 def test_provide_user(salt_factories, configure_kwargs):
-    minion_config = salt_factories.get_salt_minion_daemon(
+    minion_config = salt_factories.salt_minion_daemon(
         random_string("minion-"), **configure_kwargs
     ).config
     if not configure_kwargs:
@@ -112,19 +112,19 @@ def test_provide_user(salt_factories, configure_kwargs):
 @pytest.mark.parametrize(
     "configure_kwargs",
     [
-        {"config_defaults": None},
-        {"config_overrides": None},
+        {"defaults": None},
+        {"overrides": None},
         {},
-        {"config_defaults": None, "config_overrides": {"user": "blah"}},
-        {"config_defaults": {"user": "blah"}, "config_overrides": None},
-        {"config_defaults": {"user": "blah"}, "config_overrides": {"user": "blah"}},
+        {"defaults": None, "overrides": {"user": "blah"}},
+        {"defaults": {"user": "blah"}, "overrides": None},
+        {"defaults": {"user": "blah"}, "overrides": {"user": "blah"}},
     ],
     ids=configure_kwargs_ids,
 )
 def test_pytest_config(salt_factories, configure_kwargs):
     master_id = random_string("master-")
-    master = salt_factories.get_salt_master_daemon(master_id)
-    config = master.get_salt_minion_daemon(random_string("the-id-"), **configure_kwargs).config
+    master = salt_factories.salt_master_daemon(master_id)
+    config = master.salt_minion_daemon(random_string("the-id-"), **configure_kwargs).config
     config_key = "pytest-minion"
     assert config_key in config
     assert "log" in config[config_key]
