@@ -4,39 +4,39 @@ from saltfactories.utils import random_string
 from saltfactories.utils import running_username
 
 
-def test_keyword_basic_config_defaults(salt_factories):
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
-        random_string("proxy-minion-"), config_defaults={"zzzz": True}
+def test_keyword_basic_defaults(salt_factories):
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
+        random_string("proxy-minion-"), defaults={"zzzz": True}
     ).config
     assert "zzzz" in proxy_minion_config
 
 
-def test_keyword_basic_config_overrides(salt_factories):
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
-        random_string("proxy-minion-"), config_overrides={"zzzz": True}
+def test_keyword_basic_overrides(salt_factories):
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
+        random_string("proxy-minion-"), overrides={"zzzz": True}
     ).config
     assert "zzzz" in proxy_minion_config
 
 
 def test_keyword_simple_overrides_override_defaults(salt_factories):
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
         random_string("proxy-minion-"),
-        config_defaults={"zzzz": False},
-        config_overrides={"zzzz": True},
+        defaults={"zzzz": False},
+        overrides={"zzzz": True},
     ).config
     assert "zzzz" in proxy_minion_config
     assert proxy_minion_config["zzzz"] is True
 
 
 def test_keyword_nested_overrides_override_defaults(salt_factories):
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
         random_string("proxy-minion-"),
-        config_defaults={
+        defaults={
             "zzzz": False,
             "user": "foobar",
             "colors": {"black": True, "white": False},
         },
-        config_overrides={"colors": {"white": True, "grey": False}},
+        overrides={"colors": {"white": True, "grey": False}},
     ).config
     assert "zzzz" in proxy_minion_config
     assert proxy_minion_config["zzzz"] is False
@@ -45,9 +45,9 @@ def test_keyword_nested_overrides_override_defaults(salt_factories):
 
 def test_provide_root_dir(pytester, salt_factories):
     root_dir = str(pytester.mkdir("custom-root"))
-    config_defaults = {"root_dir": root_dir}
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
-        random_string("proxy_minion-"), config_defaults=config_defaults
+    defaults = {"root_dir": root_dir}
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
+        random_string("proxy_minion-"), defaults=defaults
     ).config
     assert proxy_minion_config["root_dir"] == root_dir
 
@@ -58,11 +58,11 @@ def configure_kwargs_ids(value):
 
 @pytest.mark.parametrize(
     "configure_kwargs",
-    [{"config_defaults": {"user": "blah"}}, {"config_overrides": {"user": "blah"}}, {}],
+    [{"defaults": {"user": "blah"}}, {"overrides": {"user": "blah"}}, {}],
     ids=configure_kwargs_ids,
 )
 def test_provide_user(salt_factories, configure_kwargs):
-    proxy_minion_config = salt_factories.get_salt_proxy_minion_daemon(
+    proxy_minion_config = salt_factories.salt_proxy_minion_daemon(
         random_string("proxy-minion-"), **configure_kwargs
     ).config
     if not configure_kwargs:
@@ -78,21 +78,19 @@ def test_provide_user(salt_factories, configure_kwargs):
 @pytest.mark.parametrize(
     "configure_kwargs",
     [
-        {"config_defaults": None},
-        {"config_overrides": None},
+        {"defaults": None},
+        {"overrides": None},
         {},
-        {"config_defaults": None, "config_overrides": {"user": "blah"}},
-        {"config_defaults": {"user": "blah"}, "config_overrides": None},
-        {"config_defaults": {"user": "blah"}, "config_overrides": {"user": "blah"}},
+        {"defaults": None, "overrides": {"user": "blah"}},
+        {"defaults": {"user": "blah"}, "overrides": None},
+        {"defaults": {"user": "blah"}, "overrides": {"user": "blah"}},
     ],
     ids=configure_kwargs_ids,
 )
 def test_pytest_config(salt_factories, configure_kwargs):
     master_id = random_string("master-")
-    master = salt_factories.get_salt_master_daemon(master_id)
-    config = master.get_salt_proxy_minion_daemon(
-        random_string("the-id-"), **configure_kwargs
-    ).config
+    master = salt_factories.salt_master_daemon(master_id)
+    config = master.salt_proxy_minion_daemon(random_string("the-id-"), **configure_kwargs).config
     config_key = "pytest-minion"
     assert config_key in config
     assert "log" in config[config_key]
