@@ -7,8 +7,8 @@
 from unittest import mock
 
 
-def test_skipped(testdir):
-    testdir.makepyfile(
+def test_skipped(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -19,13 +19,13 @@ def test_skipped(testdir):
     )
     return_value = True
     with mock.patch("saltfactories.utils.platform.is_openbsd", return_value=return_value):
-        res = testdir.runpytest_inprocess()
+        res = pytester.runpytest_inprocess()
         res.assert_outcomes(skipped=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
 
 
-def test_not_skipped(testdir):
-    testdir.makepyfile(
+def test_not_skipped(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -36,13 +36,13 @@ def test_not_skipped(testdir):
     )
     return_value = False
     with mock.patch("saltfactories.utils.platform.is_openbsd", return_value=return_value):
-        res = testdir.runpytest_inprocess()
+        res = pytester.runpytest_inprocess()
         res.assert_outcomes(passed=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
 
 
-def test_skip_reason(testdir):
-    testdir.makepyfile(
+def test_skip_reason(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -53,6 +53,6 @@ def test_skip_reason(testdir):
     )
     return_value = True
     with mock.patch("saltfactories.utils.platform.is_openbsd", return_value=return_value):
-        res = testdir.runpytest_inprocess("-ra", "-s", "-vv")
+        res = pytester.runpytest_inprocess("-ra", "-s", "-vv")
         res.assert_outcomes(skipped=1)
     res.stdout.fnmatch_lines(["SKIPPED * test_skip_reason.py:*: Because!"])
