@@ -13,8 +13,8 @@ import pytest
     "platform",
     ["windows", "linux", "darwin", "sunos", "smartos", "freebsd", "netbsd", "openbsd", "aix"],
 )
-def test_skipped(testdir, platform):
-    testdir.makepyfile(
+def test_skipped(pytester, platform):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -29,7 +29,7 @@ def test_skipped(testdir, platform):
     with mock.patch(
         "saltfactories.utils.platform.is_{}".format(platform), return_value=return_value
     ):
-        res = testdir.runpytest_inprocess()
+        res = pytester.runpytest_inprocess()
         res.assert_outcomes(skipped=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
 
@@ -38,8 +38,8 @@ def test_skipped(testdir, platform):
     "platform",
     ["windows", "linux", "darwin", "sunos", "smartos", "freebsd", "netbsd", "openbsd", "aix"],
 )
-def test_not_skipped(testdir, platform):
-    testdir.makepyfile(
+def test_not_skipped(pytester, platform):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -54,13 +54,13 @@ def test_not_skipped(testdir, platform):
     with mock.patch(
         "saltfactories.utils.platform.is_{}".format(platform), return_value=return_value
     ):
-        res = testdir.runpytest_inprocess()
+        res = pytester.runpytest_inprocess()
         res.assert_outcomes(passed=1)
     res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
 
 
-def test_skip_reason(testdir):
-    testdir.makepyfile(
+def test_skip_reason(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -71,13 +71,13 @@ def test_skip_reason(testdir):
     )
     return_value = False
     with mock.patch("saltfactories.utils.platform.is_windows", return_value=return_value):
-        res = testdir.runpytest_inprocess("-ra", "-s", "-vv")
+        res = pytester.runpytest_inprocess("-ra", "-s", "-vv")
         res.assert_outcomes(skipped=1)
     res.stdout.fnmatch_lines(["SKIPPED * test_skip_reason.py:*: Because!"])
 
 
-def test_no_platforms(testdir):
-    testdir.makepyfile(
+def test_no_platforms(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -86,16 +86,16 @@ def test_no_platforms(testdir):
             assert True
         """
     )
-    res = testdir.runpytest_inprocess()
+    res = pytester.runpytest_inprocess()
     res.stdout.fnmatch_lines(
         [
-            "* RuntimeError: Pass at least one platform to skip_unless_on_platforms as a keyword argument"
+            "*UsageError: Pass at least one platform to skip_unless_on_platforms as a keyword argument"
         ]
     )
 
 
-def test_all_platforms_false(testdir):
-    testdir.makepyfile(
+def test_all_platforms_false(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -104,16 +104,16 @@ def test_all_platforms_false(testdir):
             assert True
         """
     )
-    res = testdir.runpytest_inprocess()
+    res = pytester.runpytest_inprocess()
     res.stdout.fnmatch_lines(
         [
-            "* RuntimeError: Pass at least one platform with a True value to skip_unless_on_platforms as a keyword argument"
+            "*UsageError: Pass at least one platform with a True value to skip_unless_on_platforms as a keyword argument"
         ]
     )
 
 
-def test_unknown_platform(testdir):
-    testdir.makepyfile(
+def test_unknown_platform(pytester):
+    pytester.makepyfile(
         """
         import pytest
 
@@ -122,9 +122,9 @@ def test_unknown_platform(testdir):
             assert True
         """
     )
-    res = testdir.runpytest_inprocess()
+    res = pytester.runpytest_inprocess()
     res.stdout.fnmatch_lines(
         [
-            "* RuntimeError: Passed an invalid platform to skip_unless_on_platforms: on_platforms() got an unexpected keyword argument 'car'"
+            "*UsageError: Passed an invalid platform to skip_unless_on_platforms: on_platforms() got an unexpected keyword argument 'car'"
         ]
     )
