@@ -5,8 +5,8 @@ from saltfactories.utils import random_string
 
 @pytest.fixture(scope="module")
 def master(salt_factories):
-    factory = salt_factories.get_salt_master_daemon(
-        random_string("master-"), config_overrides={"max_open_files": 4096}
+    factory = salt_factories.salt_master_daemon(
+        random_string("master-"), overrides={"max_open_files": 4096}
     )
     return factory
 
