@@ -27,7 +27,7 @@ def proxy_minion(master):
 
 @pytest.fixture
 def salt_cli(master):
-    return master.get_salt_cli()
+    return master.salt_cli()
 
 
 @pytest.fixture
