@@ -12,13 +12,13 @@ pytestmark = pytest.mark.skipif(
 
 @pytest.fixture(scope="module")
 def master(salt_factories):
-    factory = salt_factories.get_salt_master_daemon(random_string("master-"))
+    factory = salt_factories.salt_master_daemon(random_string("master-"))
     with factory.started():
         yield factory
 
 
 def test_multiple_start_stops(master):
-    factory = master.get_salt_proxy_minion_daemon(random_string("proxy-minion-"))
+    factory = master.salt_proxy_minion_daemon(random_string("proxy-minion-"))
     assert factory.is_running() is False
     pid = None
     with factory.started():
