@@ -4,11 +4,11 @@
 
     Test the "skip_if_no_local_network" marker helper
 """
-import socket
 from unittest import mock
 
 import saltfactories.utils.markers as markers
 from saltfactories.utils import ports
+from saltfactories.utils import socket
 
 
 def test_has_local_network():
@@ -20,9 +20,9 @@ def test_no_local_network():
     mock_socket.bind = mock.MagicMock(side_effect=socket.error)
     with mock.patch(
         "saltfactories.utils.ports.get_unused_localhost_port",
-        side_effect=[ports.get_unused_localhost_port(), ports.get_unused_localhost_port()],
+        side_effect=[ports.get_unused_localhost_port() for n in range(10)],
     ):
-        with mock.patch("socket.socket", return_value=mock_socket):
+        with mock.patch("saltfactories.utils.markers.socket.socket", return_value=mock_socket):
             skip_reason = markers.skip_if_no_local_network()
             assert skip_reason is not None
             assert skip_reason == "No local network was detected"
