@@ -4,10 +4,10 @@
 
     Test the "skip_if_no_remote_network" marker helper
 """
-import socket
 from unittest import mock
 
 import saltfactories.utils.markers as markers
+from saltfactories.utils import socket
 
 
 def test_has_remote_network():
@@ -17,7 +17,7 @@ def test_has_remote_network():
 def test_no_remote_network():
     mock_socket = mock.MagicMock()
     mock_socket.connect = mock.MagicMock(side_effect=socket.error)
-    with mock.patch("socket.socket", return_value=mock_socket):
+    with mock.patch("saltfactories.utils.markers.socket.socket", return_value=mock_socket):
         skip_reason = markers.skip_if_no_remote_network()
         assert skip_reason is not None
         assert skip_reason == "No internet network connection was detected"
