@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.unit.utils.markers.test_skip_if_not_root
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -6,8 +5,7 @@
     Test the "skip_if_not_root" marker helper
 """
 import sys
-
-import mock
+from unittest import mock
 
 import saltfactories.utils.markers
 
