@@ -33,6 +33,7 @@ def test_generate_script_defaults(tmpdir):
         os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -50,6 +51,18 @@ def test_generate_script_defaults(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -85,6 +98,7 @@ def test_generate_script_code_dir(tmpdir):
         sys.path.insert(0, CODE_DIR)
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -102,6 +116,18 @@ def test_generate_script_code_dir(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -151,6 +177,7 @@ def test_generate_script_inject_coverage(tmpdir):
         os.environ[str('COVERAGE_PROCESS_START')] = str(COVERAGE_PROCESS_START)
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -168,6 +195,18 @@ def test_generate_script_inject_coverage(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -234,6 +273,7 @@ def test_generate_script_inject_sitecustomize(tmpdir):
         sys.path.insert(0, SITECUSTOMIZE_DIR)
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -251,6 +291,18 @@ def test_generate_script_inject_sitecustomize(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -295,6 +347,7 @@ def test_generate_script_inject_sitecustomize(tmpdir):
         sys.path.insert(0, SITECUSTOMIZE_DIR)
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar_2
 
         def main():
@@ -312,6 +365,18 @@ def test_generate_script_inject_sitecustomize(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -343,6 +408,7 @@ def test_generate_script_salt(tmpdir):
         os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
 
         import atexit
+        import traceback
         from salt.scripts import salt_main
 
         if __name__ == '__main__':
@@ -351,6 +417,18 @@ def test_generate_script_salt(tmpdir):
                 salt_main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -380,6 +458,7 @@ def test_generate_script_salt_api(tmpdir):
         os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
 
         import atexit
+        import traceback
         import salt.cli.api
         import salt.utils.process
 
@@ -395,6 +474,18 @@ def test_generate_script_salt_api(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -424,6 +515,7 @@ def test_generate_script_creates_missing_bin_dir(tmpdir):
         os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -441,6 +533,18 @@ def test_generate_script_creates_missing_bin_dir(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
@@ -471,6 +575,7 @@ def test_generate_script_only_generates_once(tmpdir):
         os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
 
         import atexit
+        import traceback
         from salt.scripts import salt_foobar
 
         def main():
@@ -488,6 +593,18 @@ def test_generate_script_only_generates_once(tmpdir):
                 main()
             except SystemExit as exc:
                 exitcode = exc.code
+                # https://docs.python.org/3/library/exceptions.html#SystemExit
+                if exitcode is None:
+                    exitcode = 0
+                if not isinstance(exitcode, int):
+                    # A string?!
+                    sys.stderr.write(exitcode)
+                    exitcode = 1
+            except Exception as exc:
+                sys.stderr.write(
+                    "An un-handled exception was caught: " + str(exc) + "\\n" + traceback.format_exc()
+                )
+                exitcode = 1
             sys.stdout.flush()
             sys.stderr.flush()
             atexit._run_exitfuncs()
